@@ -1,5 +1,5 @@
 /* AisleRiot - card.h
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #define CARD_H
 
 #include <gnome.h>
-#include "../freecell/gdk-card-image/gdk-card-image.h"
+#include "gdk-card-image.h"
 
 /*
  * Constants
@@ -51,19 +51,19 @@ extern GdkBitmap *mask;
  * Functions
  */
 GdkPixmap* get_card_picture (gint, gint);
-GdkPixmap* get_slot_pixmap ();
-GdkPixmap* get_background_pixmap ();
-GdkPixmap* get_card_back_pixmap ();
+GdkPixbuf* get_slot_pixbuf ( void );
+GdkPixmap* get_background_pixmap ( void );
+GdkPixmap* get_card_back_pixmap ( void );
 
 void load_pixmaps (GtkWidget*, GdkCardDeckOptions);
 void free_pixmaps (void);
 
-int get_card_width ();
-int get_card_height ();
-int get_horiz_offset ();
-int get_vert_offset ();
-int get_vert_start ();
-int get_horiz_start ();
+int get_card_width ( void );
+int get_card_height ( void );
+int get_horiz_offset ( void );
+int get_vert_offset ( void );
+int get_vert_start ( void );
+int get_horiz_start ( void );
 
 void add_card (GList**, hcard_type);
 #endif
