@@ -1,5 +1,5 @@
 /* AisleRiot - events.c
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,15 +24,10 @@
 #include "dialog.h"
 #include "slot.h"
 
-static guint32
-get_current_time (void)
-{
-	GTimeVal tval;
-
-	g_get_current_time (&tval);
-
-	return tval.tv_sec;
-}
+hslot_type last_hslot;
+gint last_cardid;
+GTimer * click_timer = NULL;
+gdouble dbl_click_time;
 
 int waiting_for_mouse_up(void) {
   if (!press_data) return 0;
@@ -99,9 +94,9 @@ void drop_moving_cards(gint x, gint y) {
   gdk_window_hide(press_data->moving_cards);
 
   if (press_data->moving_pixmap)
-    gdk_drawable_unref(press_data->moving_pixmap);
+    g_object_unref(press_data->moving_pixmap);
   if (press_data->moving_mask)
-    gdk_drawable_unref(press_data->moving_mask);
+    g_object_unref(press_data->moving_mask);
   press_data->moving_pixmap = NULL;
   press_data->moving_mask = NULL;
 
@@ -112,41 +107,47 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 {
   hslot_type hslot;
   gint cardid;
-  static guint dbl_click_time = 250;
-  static int first_press;
+  gboolean double_click;
 
-  /* We only want first mouse click*/
-  if (event->button != 1)
-	  return TRUE;
-  
-  /* ignore the gdk synthetic click events */
-  if (event->type != GDK_BUTTON_PRESS && event->type != GDK_2BUTTON_PRESS)
+  if (event->button != 1 && event->button != 3)
     return TRUE;
   
-  if (press_data->status == STATUS_IS_DRAG ||
-      (press_data->status == STATUS_SHOW || press_data->status == STATUS_IS_DRAG))
+  /* ignore the gdk synthetic click events */
+  if (event->type != GDK_BUTTON_PRESS)
+    return TRUE;
+  
+  if (press_data->status == STATUS_SHOW || press_data->status == STATUS_IS_DRAG)
     return TRUE;
 
   slot_pressed(event->x, event->y, &hslot, &cardid);
 
   if (!hslot)
     return TRUE;
+
+  /* We can't let Gdk do the double-click detection since the entire playing
+   * area is one big widget it can't distinguish between single-clicks on two
+   * cards and a double-click on one. */
+  double_click = (g_timer_elapsed(click_timer,NULL) < dbl_click_time)
+    && (last_cardid == cardid)
+    && (last_hslot->id == hslot->id)
+    && (event->button != 3);
+  g_timer_start(click_timer);
+  slot_pressed(event->x, event->y, &last_hslot, &last_cardid);
+
   press_data->xoffset = event->x;
   press_data->yoffset = event->y;
   press_data->hslot = hslot;
   press_data->cardid = cardid;
-  if (!(press_data->status == STATUS_CLICK && event->button == GDK_2BUTTON_PRESS)) {
-    first_press = get_current_time();
-    press_data->status = cardid > 0 ? STATUS_MAYBE_DRAG : STATUS_NOT_DRAG;
-  }
-  if (cardid > 0 && press_data->status == STATUS_NONE) {
+
+  if (cardid > 0 && (press_data->status == STATUS_NONE || press_data->status == STATUS_CLICK)
+      && event->button == 3) {
     hcard_type card = g_list_nth(hslot->cards, cardid - 1)->data;
-    
+
     if (card->direction == UP) {      
       guint delta = hslot->exposed - (hslot->length - cardid) - 1;
       int x = hslot->x + delta * hslot->dx;
       int y = hslot->y + delta * hslot->dy;
-      
+
       press_data->status = STATUS_SHOW;
       press_data->moving_pixmap = get_card_picture (card->suit, card->value);
       press_data->moving_mask = mask;
@@ -159,16 +160,21 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
       gdk_window_move(press_data->moving_cards, x, y); 
       gdk_window_show(press_data->moving_cards);
     }
+    return TRUE;
   } 
-  else if (event->type == GDK_2BUTTON_PRESS) {
-    press_data->status == STATUS_NONE;
+  
+  if (!(press_data->status == STATUS_CLICK && double_click)) {
+    press_data->status = cardid > 0 ? STATUS_MAYBE_DRAG : STATUS_NOT_DRAG;
+  }
+  if (double_click) {
+    press_data->status = STATUS_NONE;
     gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
 	      SCM_EOL);
     if (gh_scm2bool (gh_call1 (game_data->button_double_clicked_lambda,
-		     gh_long2scm (hslot->id))))
-	    gh_call0 (gh_eval_str ("end-move"));
+                               gh_long2scm (hslot->id))))
+      gh_call0 (gh_eval_str ("end-move"));
     else
-	    gh_call0 (gh_eval_str ("discard-move"));
+      gh_call0 (gh_eval_str ("discard-move"));
     refresh_screen ();
     end_of_game_test ();
     return TRUE;
@@ -178,18 +184,20 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
 gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 {
-  if (event->button != 1) return TRUE;
-  switch (press_data->status) {
-  case STATUS_IS_DRAG:
-    press_data->status = STATUS_NONE;
-    drop_moving_cards(event->x, event->y);
-    break;
-    
-  case STATUS_SHOW:
+  if (event->button == 3 && press_data->status == STATUS_SHOW) {
     press_data->status = STATUS_NONE;
     gdk_window_hide(press_data->moving_cards);
     press_data->moving_pixmap = NULL;
     press_data->moving_mask = NULL;
+    return TRUE;
+  }
+
+  if (event->button != 1)
+    return TRUE;
+  switch (press_data->status) {
+  case STATUS_IS_DRAG:
+    press_data->status = STATUS_NONE;
+    drop_moving_cards(event->x, event->y);
     break;
     
   case STATUS_MAYBE_DRAG:
@@ -215,9 +223,7 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
 gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 {
-/*g_print ("move\n");*/
   if (press_data->status == STATUS_IS_DRAG) {
-/*g_print ("keep movin\n");*/
     gdk_window_move(press_data->moving_cards,  
 		    event->x - press_data->xoffset,
 		    event->y - press_data->yoffset);
@@ -230,7 +236,6 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
     hslot_type hslot = press_data->hslot;
     GList* glist = g_list_nth(hslot->cards, press_data->cardid - 1); 
     SCM cardlist = SCM_EOL;
-/*g_print ("maybe move\n");*/
     
     for (; glist; glist = glist->next)
       cardlist = gh_cons(make_card((hcard_type)glist->data), cardlist);
@@ -249,13 +254,16 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 }
 
 gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
+  gint tmptime;
+  GtkSettings * settings;
+
   if(surface) {
     gint old_w, old_h;
 
     gdk_drawable_get_size(surface, &old_w, &old_h);
     if(old_w == event->width && old_h == event->height)
       return TRUE;
-    gdk_drawable_unref(surface);
+    g_object_unref(surface);
   }
   else {
     timer_start();
@@ -267,6 +275,13 @@ gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
   
   refresh_screen();
 
+  /* Set up the double-click detection.*/
+  if (!click_timer)
+    click_timer = g_timer_new();
+  settings = gtk_settings_get_default();
+  g_object_get(G_OBJECT(settings),"gtk-double-click-time",&tmptime,NULL);
+  dbl_click_time = tmptime/1000.0;
+  
   return FALSE;
 }
 
