@@ -1,5 +1,5 @@
 /* AisleRiot - events.h
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,16 @@ gint button_press_event (GtkWidget*, GdkEventButton*, void* );
 gint button_release_event (GtkWidget*, GdkEventButton*, void* );
 gint configure_event (GtkWidget*, GdkEventConfigure* );
 gint motion_notify_event (GtkWidget*, GdkEventMotion* );
-void end_of_game_test();
+void end_of_game_test(void);
+int waiting_for_mouse_up(void);
 
+enum {
+  STATUS_NONE,
+  STATUS_MAYBE_DRAG,
+  STATUS_NOT_DRAG,
+  STATUS_IS_DRAG,
+  STATUS_CLICK,
+  STATUS_SHOW
+};
 
 #endif
