@@ -34,7 +34,7 @@ GnibblesWarpManager *gnibbles_warpmanager_new ()
 	int i;
 	GnibblesWarpManager *tmp;
 
-	tmp = (GnibblesWarpManager *) malloc (sizeof (GnibblesWarpManager));
+	tmp = (GnibblesWarpManager *) g_malloc (sizeof (GnibblesWarpManager));
 	for (i = 0; i < MAXWARPS; i++)
 		tmp->warps[i] = NULL;
 	tmp->numwarps = 0;
@@ -53,9 +53,9 @@ void gnibbles_warpmanager_destroy (GnibblesWarpManager *warpmanager)
 }
 
 void gnibbles_warpmanager_add_warp (GnibblesWarpManager *warpmanager, gint t_x,
-		gint t_y, gint t_wx, gint t_wy)
+                                    gint t_y, gint t_wx, gint t_wy)
 {
-	gint i, add = 1, draw;
+	gint i, add = 1, draw = 0;
 
 	if (t_x < 0) {
 		for (i = 0; i < warpmanager->numwarps; i++) {
