@@ -1,6 +1,8 @@
-/* gnome-stones - object.h
+/* -*- mode:C; indent-tabs-mode:t; tab-width:8; c-basic-offset:2; -*- */
+
+/* gnome-stones - object.c
  *
- * Time-stamp: <2002/05/02 16:59:46 dave>
+ * Time-stamp: <2003/06/19 21:12:50 mccannwj>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -128,28 +130,31 @@ plugin_load (const gchar *filename)
 }
 
 
+#define SOEXT ("." G_MODULE_SUFFIX)
+#define SOEXT_LEN (strlen (SOEXT))
+
 void
 plugin_load_plugins_in_dir (const gchar *directory)
 {
-  DIR *d;
-  struct dirent *e;
+  GDir *d;
+  G_CONST_RETURN gchar *e;
   
-  if ((d = opendir (directory)) == NULL)
+  if ((d = g_dir_open (directory, 0, NULL)) == NULL)
     return;
   
-  while ((e = readdir (d)) != NULL)
+  while ((e = g_dir_read_name (d)) != NULL)
     {
-      if ((strlen (e->d_name) > 3) &&  
-	  (strncmp (e->d_name + strlen (e->d_name) - 3, ".so", 3) == 0))
+      if ((strlen (e) > SOEXT_LEN) &&  
+	  (strncmp (e + strlen (e) - SOEXT_LEN, SOEXT, SOEXT_LEN) == 0))
 	{
-	  char *objects_name;
+	  gchar *objects_name;
 	  
-	  objects_name = g_strconcat (directory, e->d_name, NULL);
+	  objects_name = g_build_filename (directory, e, NULL);
 	  plugin_load (objects_name);
 	  g_free (objects_name);
 	}
     }
-  closedir (d);
+  g_dir_close (d);
 }
 
 
@@ -203,7 +208,7 @@ static GStonesObjectDesc curtain_description=
 };
 
 
-gchar *
+static gchar *
 default_objects_init (GStonesPlugin *plugin)
 {
   object_register (plugin, &frame_description);
@@ -223,7 +228,7 @@ static GStonesPlugin default_plugin=
 };
 
 
-void
+static void
 default_objects_register (void)
 {
   /* The frame object has only to be registered once.  */
@@ -247,8 +252,8 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   guint          x;
   guint          y;
   guint          idx;
-  char          *filename;
-  char          *pathname;
+  gchar          *filename;
+  gchar          *pathname;
   GdkPixbuf *image;
   GStonesObject *object;
 
@@ -260,18 +265,17 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   object->description= description;
   object->plugin     = plugin;
 
-  filename= g_strconcat ("gnome-stones/", description->image_name, NULL);
-  pathname=  gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-                                        filename, TRUE, NULL);
+  filename= g_build_filename ("gnome-stones", description->image_name, NULL);
+  pathname= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
+                                       filename, TRUE, NULL);
   image   = gdk_pixbuf_new_from_file (pathname, NULL);
   g_free (pathname);
   g_free (filename);
   
   if (!image)
     {
-      char *error= g_strconcat ("Error while loading image ", 
-				   description->image_name, 
-				   ": file not found!", NULL);
+      gchar *error= g_strdup_printf ("Error while loading image %s: file not found!", 
+                                    description->image_name);
       g_warning (error);
       g_free (error);
 
@@ -284,9 +288,8 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
 
   if (num_x*num_y == 0)
     {
-      char *error= g_strconcat ("Error while registering object ", 
-				   description->image_name, 
-				   ": image contains no data!", NULL);
+      gchar *error= g_strdup_printf ("Error while registering object %s: image contains no data!", 
+                                     description->image_name);
       g_warning (error);
       g_free (error);
 
@@ -298,9 +301,8 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   
   if (object->image == NULL)
     {
-      char *error= g_strconcat ("Error while registering object ", 
-				   description->image_name, 
-				   ": out of memory!", NULL);
+      char *error= g_strdup_printf ("Error while registering object %s: out of memory!", 
+                                    description->image_name);
       g_warning (error);
       g_free (error);
 
@@ -311,9 +313,8 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   
   if (object->pixbuf_image == NULL)
     {
-      char *error= g_strconcat ("Error while registering object ", 
-				   description->image_name, 
-				   ": out of memory!", NULL);
+      char *error= g_strdup_printf ("Error while registering object %s: out of memory!", 
+                                    description->image_name);
       g_warning (error);
       g_free (error);
       g_free (object->image);
