@@ -1,13 +1,47 @@
+/* -*- mode:C; indent-tabs-mode:t; tab-width:8; c-basic-offset:8; -*- */
+
+/*
+ * Properties.c - Properties and preferences part of iagno
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * For more details see the file COPYING.
+ */
+
 #include <config.h>
 #include <gnome.h>
+#include <string.h>
 #include <dirent.h>
 #include <gconf/gconf-client.h>
+#include <games-gconf.h>
 #include <games-clock.h>
+#include <games-frame.h>
 
 #include "properties.h"
 #include "gnothello.h"
 #include "othello.h"
 
+#define KEY_TILESET "/apps/iagno/tileset"
+#define KEY_BLACK_LEVEL "/apps/iagno/black_level"
+#define KEY_WHITE_LEVEL "/apps/iagno/white_level"
+#define KEY_QUICK_MOVES "/apps/iagno/quick_moves"
+#define KEY_ANIMATE "/apps/iagno/animate"
+#define KEY_ANIMATE_STAGGER "/apps/iagno/animate_stagger"
+#define KEY_SHOW_GRID "/apps/iagno/show_grid"
+#define KEY_FLIP_FINAL_RESULTS "/apps/iagno/flip_final_results"
+
 static GtkWidget *propbox = NULL;
 
 extern GtkWidget *window;
@@ -35,7 +69,7 @@ gint t_animate_stagger;
 gint t_flip_final;
 gint t_grid;
 
-int mapped = 0;
+static void apply_changes (void);
 
 /*
  * FIXME:
@@ -43,28 +77,43 @@ int mapped = 0;
  *	It doesn't abide by the HIG.
  */
 
-void load_properties ()
+static gint clamp_int (gint input, gint low, gint high)
+{
+        if (input < low)
+                input = low;
+        if (input > high)
+                input = high;
+
+        return input;
+}
+
+void 
+load_properties (void)
 {
 	GConfClient *client;
 	GError      *error = NULL;
 
 	client = gconf_client_get_default ();
-
-	black_computer_level = gconf_client_get_int (client, "/apps/iagno/black-level", &error);
+	if (!games_gconf_sanity_check_string (client, KEY_TILESET)) {
+		exit(1);
+	}
+	black_computer_level = gconf_client_get_int (client, KEY_BLACK_LEVEL, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-
-	white_computer_level = gconf_client_get_int (client, "/apps/iagno/white-level", &error);
+        black_computer_level = clamp_int (black_computer_level, 0, 3);
+	
+	white_computer_level = gconf_client_get_int (client, KEY_WHITE_LEVEL, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-
-	if (gconf_client_get_bool (client, "/apps/iagno/quick-moves", &error))
+        white_computer_level = clamp_int (white_computer_level, 0, 3);
+	
+	if (gconf_client_get_bool (client, KEY_QUICK_MOVES, &error))
 		computer_speed = COMPUTER_MOVE_DELAY / 2;
 	else
 		computer_speed = COMPUTER_MOVE_DELAY;
@@ -78,35 +127,38 @@ void load_properties ()
 	if (tile_set)
 		g_free (tile_set);
 
-	tile_set = gconf_client_get_string (client, "/apps/iagno/tileset", &error);
+	tile_set = gconf_client_get_string (client, KEY_TILESET, &error);
+	if (error) {
+		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
+	if (tile_set == NULL)
+		tile_set = g_strdup ("classic.png");
+	
+	animate = gconf_client_get_int (client, KEY_ANIMATE, &error);
+	if (error) {
+		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
+        animate = clamp_int (animate, 0, 2);
+
+	animate_stagger = gconf_client_get_bool (client, KEY_ANIMATE_STAGGER, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
 
-	animate = gconf_client_get_int (client, "/apps/iagno/animate", &error);
+	grid = gconf_client_get_bool (client, KEY_SHOW_GRID, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
 
-	animate_stagger = gconf_client_get_bool (client, "/apps/iagno/animate-stagger", &error);
-	if (error) {
-		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
-		g_error_free (error);
-		error = NULL;
-	}
-
-	grid = gconf_client_get_bool (client, "/apps/iagno/show-grid", &error);
-	if (error) {
-		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
-		g_error_free (error);
-		error = NULL;
-	}
-
-	flip_final = gconf_client_get_bool (client, "/apps/iagno/flip-final-results", &error);
+	flip_final = gconf_client_get_bool (client, KEY_FLIP_FINAL_RESULTS, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
@@ -125,32 +177,39 @@ void load_properties ()
 		flip_pixmaps_id = g_timeout_add (PIXMAP_FLIP_DELAY, flip_pixmaps, NULL);
 		break;
 	}
+
+	g_object_unref (client);
 }
 
-void reset_properties ()
+static void
+reset_properties (void)
 {
 	GConfClient *client;
 	GError      *error = NULL;
 
 	client = gconf_client_get_default ();
 
-	t_black_computer_level = black_computer_level =
-		gconf_client_get_int (client, "/apps/iagno/black-level", &error);
+	black_computer_level =
+		gconf_client_get_int (client, KEY_BLACK_LEVEL, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
+        t_black_computer_level = black_computer_level
+		= clamp_int (black_computer_level, 0, 3);
 
-	t_white_computer_level = white_computer_level =
-		gconf_client_get_int (client, "/apps/iagno/white-level", &error);
+	white_computer_level =
+		gconf_client_get_int (client, KEY_WHITE_LEVEL, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-
-	t_quick_moves = gconf_client_get_bool (client, "/apps/iagno/quick-moves", &error);
+        t_white_computer_level = white_computer_level
+		= clamp_int (white_computer_level, 0, 3);
+	
+	t_quick_moves = gconf_client_get_bool (client, KEY_QUICK_MOVES, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
@@ -160,75 +219,123 @@ void reset_properties ()
 	if (tile_set_tmp)
 		g_free (tile_set_tmp);
 
-	tile_set_tmp = gconf_client_get_string (client, "/apps/iagno/tileset", &error);
+	tile_set_tmp = gconf_client_get_string (client, KEY_TILESET, &error);
 	if (error) {
 		g_warning (G_STRLOC ": gconf error: %s\n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-
+	if (tile_set_tmp == NULL)
+		tile_set_tmp = g_strdup("classic.png");
+	
 	t_animate         = animate;
 	t_animate_stagger = animate_stagger;
 	t_grid            = grid;
 	t_flip_final      = flip_final;
+
+	g_object_unref (client);
 }
 
-void black_computer_level_select (GtkWidget *widget, gpointer data)
+static void 
+black_computer_level_select (GtkWidget *widget, gpointer data)
 {
-	if (((guint) data != t_black_computer_level) &&
-		       (GTK_TOGGLE_BUTTON (widget)->active)) {
+	if (((guint) data != t_black_computer_level) 
+	    && (GTK_TOGGLE_BUTTON (widget)->active)) {
 		t_black_computer_level = (guint) data;
+		apply_changes ();
 	}
 }
 
-void white_computer_level_select (GtkWidget *widget, gpointer data)
+static void 
+white_computer_level_select (GtkWidget *widget, gpointer data)
 {
-	if (((guint) data != t_white_computer_level) &&
-		       (GTK_TOGGLE_BUTTON (widget)->active)) {
+	if (((guint) data != t_white_computer_level)
+	    && (GTK_TOGGLE_BUTTON (widget)->active)) {
 		t_white_computer_level = (guint) data;
+		apply_changes ();
 	}
 }
 
-void quick_moves_select (GtkWidget *widget, gpointer data)
+static void 
+quick_moves_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active)
 		t_quick_moves = 1;
 	else
 		t_quick_moves = 0;
+	apply_changes ();
 }
 
-void flip_final_select (GtkWidget *widget, gpointer data)
+static void 
+flip_final_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active)
 		t_flip_final = 1;
 	else
 		t_flip_final = 0;
+	apply_changes ();	
 }
 
-void animate_stagger_select (GtkWidget *widget, gpointer data)
+static void
+animate_stagger_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active)
 		t_animate_stagger = 1;
 	else
 		t_animate_stagger = 0;
+	apply_changes ();	
 }
 
-void grid_select (GtkWidget *widget, gpointer data)
+static void
+grid_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active)
 		t_grid = 1;
 	else
 		t_grid = 0;
+	apply_changes ();
 }
 
-void animate_select (GtkWidget *widget, gpointer data)
+static void
+animate_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
 		t_animate = (gint) data;
 	}
+	apply_changes ();	
 }
 
-void apply_changes ()
+static void
+save_properties (void)
+{
+	GConfClient *client;
+
+	client = gconf_client_get_default ();
+
+	gconf_client_set_int (client, KEY_BLACK_LEVEL,
+			      black_computer_level, NULL);
+	gconf_client_set_int (client, KEY_WHITE_LEVEL,
+			      white_computer_level, NULL);
+
+	gconf_client_set_bool (client, KEY_QUICK_MOVES,
+			       t_quick_moves, NULL);
+
+	gconf_client_set_string (client, KEY_TILESET,
+				 tile_set_tmp, NULL);
+
+	gconf_client_set_int (client, KEY_ANIMATE,
+			      animate, NULL);
+
+	gconf_client_set_bool (client, KEY_ANIMATE_STAGGER,
+			       animate_stagger, NULL);
+	gconf_client_set_bool (client, KEY_SHOW_GRID,
+			       grid, NULL);
+	gconf_client_set_bool (client, KEY_FLIP_FINAL_RESULTS,
+			       flip_final, NULL);
+}
+
+static void
+apply_changes (void)
 {
 	guint i, j;
 	
@@ -262,7 +369,7 @@ void apply_changes ()
 		g_free (tile_set);
 		tile_set = g_strdup (tile_set_tmp);
 		load_pixmaps ();
-	    set_bg_color();
+		set_bg_color ();
 		for (i = 0; i < 8; i++)
 			for (j = 0; j < 8; j++)
 				if (pixmaps [i][j] >= BLACK_TURN &&
@@ -283,14 +390,14 @@ void apply_changes ()
 	switch (animate) {
 		case 0:
 			flip_pixmaps_id = gtk_timeout_add (100, flip_pixmaps,
-					NULL);
+							   NULL);
 			break;
 		case 1:
-			flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY *
-					8, flip_pixmaps, NULL);
+			flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY * 8,
+							   flip_pixmaps, NULL);
 			break;
 		case 2: flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY,
-					flip_pixmaps, NULL);
+							   flip_pixmaps, NULL);
 			break;
 	}
 	
@@ -298,74 +405,53 @@ void apply_changes ()
 
 	flip_final = t_flip_final;
 
-	if (grid!=t_grid) {
+	if (grid != t_grid) {
 			grid = t_grid;
-			gui_draw_grid();
+			gui_draw_grid ();
 	}
 
 	check_computer_players ();
-}
 
-void save_properties ()
-{
-	GConfClient *client;
-
-	client = gconf_client_get_default ();
-
-	gconf_client_set_int (client, "/apps/iagno/black-level",
-			      black_computer_level, NULL);
-	gconf_client_set_int (client, "/apps/iagno/white-level",
-			      white_computer_level, NULL);
-
-	gconf_client_set_bool (client, "/apps/iagno/quick-moves",
-			       t_quick_moves, NULL);
-
-	gconf_client_set_string (client, "/apps/iagno/tileset",
-				 tile_set_tmp, NULL);
-
-	gconf_client_set_int (client, "/apps/iagno/animate",
-			      animate, NULL);
-
-	gconf_client_set_bool (client, "/apps/iagno/animate-stagger",
-			       animate_stagger, NULL);
-	gconf_client_set_bool (client, "/apps/iagno/show-grid",
-			       grid, NULL);
-	gconf_client_set_bool (client, "/apps/iagno/flip-final-results",
-			       flip_final, NULL);
-}
-
-void apply_cb (GtkWidget *widget, gint arg1, gpointer data)
-{
-	gtk_widget_hide (widget);
-	mapped = 0;
-
-	if (arg1 == GTK_RESPONSE_REJECT)
-		return;
-
-	apply_changes();
-	
 	save_properties ();
 }
 
-void destroy_cb (GtkWidget *widget, gpointer data)
+static void
+close_cb (GtkWidget *widget, gint arg1, gpointer data)
 {
-	mapped = 0;
+	gtk_widget_hide (widget);
+
+/*	if (arg1 == GTK_RESPONSE_REJECT)
+		return;
+
+	apply_changes ();
+	
+	save_properties (); */
 }
 
-void set_selection(GtkWidget *widget, gpointer data)
+static void
+destroy_cb (GtkWidget *widget, gpointer data)
+{
+
+}
+
+void
+set_selection (GtkWidget *widget, gpointer data)
 {
 	if (strcmp ((gchar *)data, tile_set_tmp) != 0) {
 		g_free (tile_set_tmp);
 		tile_set_tmp = g_strdup (data);
 	}
+	apply_changes ();
 }
 
-void free_str(GtkWidget *widget, void *data)
+void
+free_str (GtkWidget *widget, void *data)
 {
         g_free(data);
 }
 
-void fill_menu(GtkWidget *menu)
+void
+fill_menu (GtkWidget *menu)
 {
         struct dirent *e;
         char *dname = NULL;
@@ -373,7 +459,7 @@ void fill_menu(GtkWidget *menu)
         int itemno = 0;
 
 	dname = gnome_program_locate_file (NULL,
-			GNOME_FILE_DOMAIN_PIXMAP,  "iagno", FALSE, NULL);
+			GNOME_FILE_DOMAIN_APP_PIXMAP,  "iagno", FALSE, NULL);
         dir = opendir(dname);
 
         if(!dir)
@@ -407,26 +493,7 @@ void fill_menu(GtkWidget *menu)
 }
 
 void
-dialog_help_callback (GtkWidget *box, gint page_num)
-{
-#if 0
-  GnomeHelpMenuEntry settings_entry = { "iagno", "settings.html" };
-  GnomeHelpMenuEntry animation_entry = { "iagno", "animations.html" };
-
-  switch (page_num) {
-  case 0:
-    gnome_help_display (0, &settings_entry);
-    break;
-  case 1:
-    gnome_help_display (0, &animation_entry);
-    break;
-  default:
-    break;
-  }
-#endif
-}
-
-void show_properties_dialog ()
+show_properties_dialog (void)
 {
 	GtkWidget *notebook;
 	GtkWidget *hbox;
@@ -435,21 +502,14 @@ void show_properties_dialog ()
 	GtkWidget *table;
 	GtkWidget *button;
 	GtkWidget *frame;
-	GtkWidget *vbox;
+	GtkWidget *vbox, *vbox2;
 	GtkWidget *option_menu;
 	GtkWidget *menu;
 
 	if (propbox)
 	{
-		if (mapped == 0)
-		{
-			gtk_widget_show(propbox);
-			mapped = 1;
-			reset_properties ();
-		} else {
-			gdk_window_raise (GTK_WIDGET(propbox)->window);
-		}
-		return;
+                gtk_window_present (GTK_WINDOW (propbox));
+                return;
 	}
 
 	reset_properties ();
@@ -457,42 +517,42 @@ void show_properties_dialog ()
 	propbox = gtk_dialog_new_with_buttons (NULL,
 			GTK_WINDOW (window),
 			0,
-			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
-
-	notebook = gtk_notebook_new();
+			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+        gtk_window_set_title (GTK_WINDOW(propbox), _("Iagno Preferences"));
+        
+        gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
+	notebook = gtk_notebook_new ();
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (propbox)->vbox),
-			notebook);
-	gtk_widget_show (notebook);
-
-	vbox = gtk_vbox_new(FALSE, 8);
-	gtk_widget_show (vbox);
+                           notebook);
 
 	label = gtk_label_new (_("Players"));
-	gtk_widget_show (label);
 
-	table = gtk_table_new (2, 2, FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD);
-	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
-	gtk_widget_show (table);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
+                                  vbox, label);
+        
+        table = gtk_table_new (1, 2, FALSE);
+        gtk_container_set_border_width (GTK_CONTAINER (table), 0);
+        gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
-	button = gtk_check_button_new_with_label (_("Quick Moves"));
+	vbox2 = gtk_vbox_new (FALSE, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox2), 12);
+        gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
+
+	button = gtk_check_button_new_with_label (_("Use quick moves"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-			(computer_speed == COMPUTER_MOVE_DELAY / 2));
+                                      (computer_speed == COMPUTER_MOVE_DELAY / 2));
 	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
-			(quick_moves_select), NULL);
-	gtk_widget_show (button);
+                          (quick_moves_select), NULL);
 	
-	gtk_table_attach (GTK_TABLE (table), button, 0, 2, 1, 2,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	
-	frame = gtk_frame_new (_("Dark"));
-	gtk_widget_show (frame);
+	gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, FALSE, 0);
+        
+
+	frame = games_frame_new (_("Dark"));
+        gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 1, 0, 1);
 
 	vbox = gtk_vbox_new (TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
-	gtk_widget_show (vbox);
 
 	button = gtk_radio_button_new_with_label (NULL, _("Human"));
 	if (black_computer_level == 0)
@@ -501,7 +561,7 @@ void show_properties_dialog ()
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (black_computer_level_select),
 			(gpointer) 0);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Level one"));
@@ -511,7 +571,7 @@ void show_properties_dialog ()
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (black_computer_level_select),
 			(gpointer) 1);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Level two"));
@@ -521,7 +581,7 @@ void show_properties_dialog ()
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (black_computer_level_select),
 			(gpointer) 2);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Level three"));
@@ -531,20 +591,15 @@ void show_properties_dialog ()
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (black_computer_level_select),
 			(gpointer) 3);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	
-	frame = gtk_frame_new (_("Light"));
-	gtk_widget_show (frame);
+	frame = games_frame_new (_("Light"));
+        gtk_table_attach_defaults (GTK_TABLE (table), frame, 1, 2, 0, 1);
 	
 	vbox = gtk_vbox_new (TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
-	gtk_widget_show (vbox);
 	
 	button = gtk_radio_button_new_with_label (NULL, _("Human"));
 	if (white_computer_level == 0)
@@ -553,7 +608,7 @@ void show_properties_dialog ()
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (white_computer_level_select),
 			(gpointer) 0);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Level one"));
@@ -561,9 +616,9 @@ void show_properties_dialog ()
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 1);
-	gtk_widget_show (button);
+                          GTK_SIGNAL_FUNC (white_computer_level_select),
+                          (gpointer) 1);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Level two"));
@@ -571,44 +626,33 @@ void show_properties_dialog ()
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 2);
-	gtk_widget_show (button);
+                          GTK_SIGNAL_FUNC (white_computer_level_select),
+                          (gpointer) 2);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
-			(GTK_RADIO_BUTTON (button)), _("Level three"));
+                                                  (GTK_RADIO_BUTTON (button)),
+                                                  _("Level three"));
 	if (white_computer_level == 3)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (white_computer_level_select),
 			(gpointer) 3);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
-	gtk_notebook_append_page (GTK_NOTEBOOK(notebook),
-			table, label);
-
-	label = gtk_label_new (_("Animation"));
-	gtk_widget_show (label);
+        label = gtk_label_new (_("Appearance"));
 
 	table = gtk_table_new (1, 2, FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD);
-	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
-	gtk_widget_show (table);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 0);
 	
-	frame = gtk_frame_new (NULL);
-	gtk_widget_show (frame);
+	frame = games_frame_new (_("Animation"));
 	
-	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
-	gtk_widget_show (vbox);
+	vbox = gtk_vbox_new (FALSE, 6);
 	
 	button = gtk_radio_button_new_with_label (NULL, _("None"));
 	if (animate == 0)
@@ -616,7 +660,7 @@ void show_properties_dialog ()
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (animate_select), (gpointer) 0);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Partial"));
@@ -625,7 +669,7 @@ void show_properties_dialog ()
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (animate_select), (gpointer) 1);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Complete"));
@@ -634,23 +678,20 @@ void show_properties_dialog ()
 				TRUE);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (animate_select), (gpointer) 2);
-	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
-
-	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	
-	vbox = gtk_vbox_new (TRUE, GNOME_PAD);
-	gtk_widget_show (vbox);
+	gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 1, 0, 1);
 	
+        frame = games_frame_new (_("Options"));
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_container_add (GTK_CONTAINER (frame), vbox);
 	button = gtk_check_button_new_with_label (_("Stagger flips"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 			t_animate_stagger);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (animate_stagger_select), NULL);
-	gtk_widget_show (button);
 	
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -659,7 +700,6 @@ void show_properties_dialog ()
 			t_grid);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (grid_select), NULL);
-	gtk_widget_show (button);
 	
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -668,15 +708,12 @@ void show_properties_dialog ()
 			t_flip_final);
 	g_signal_connect (GTK_OBJECT (button), "toggled",
 			GTK_SIGNAL_FUNC (flip_final_select), NULL);
-	gtk_widget_show (button);
 
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
-	gtk_widget_show (hbox);
 	
 	label2 = gtk_label_new (_("Tile set:"));
-	gtk_widget_show (label2);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), label2, FALSE, FALSE, 0);
 	
@@ -684,25 +721,22 @@ void show_properties_dialog ()
 	menu = gtk_menu_new ();
 	fill_menu (menu);
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-	gtk_widget_show (option_menu);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), option_menu, TRUE, TRUE, 0);
 	
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	
-	gtk_table_attach (GTK_TABLE (table), vbox, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), frame, 1, 2, 0, 1);
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table,
-			label);
-
+                                  label);
+        
 	g_signal_connect (GTK_OBJECT (propbox), "response", GTK_SIGNAL_FUNC
-			(apply_cb), NULL);
+			(close_cb), NULL);
 	g_signal_connect (GTK_OBJECT (propbox), "destroy", GTK_SIGNAL_FUNC
 			(destroy_cb), NULL);
 	g_signal_connect (GTK_OBJECT (propbox), "close", GTK_SIGNAL_FUNC
 			(destroy_cb), NULL);
 
-	gtk_widget_show (propbox);
-	mapped = 1;
+	gtk_widget_show_all (propbox);
 }
